@@ -1,4 +1,4 @@
-/* $Id: weather-http.c 3602 2007-11-18 10:25:46Z nick $ */
+/* $Id: weather-http.c 7532 2009-06-11 20:26:28Z colin $ */
 /*
  * Copyright (c) 2007 Nick Schermer <nick@xfce.org>
  *
@@ -21,14 +21,17 @@
 #include <config.h>
 #endif
 
-#include <sys/socket.h>
 #include <sys/types.h>
+#include <sys/socket.h>
+#include <sys/stat.h>
 #include <errno.h>
 #include <netdb.h>
 #include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <netinet/in.h>
+#include <resolv.h>
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -117,7 +120,25 @@ weather_http_receive_data_check (WeatherConnection *connection,
   return FALSE;
 }
 
+static void refresh_resolvers(void)
+{
+#ifdef G_OS_UNIX
+	static time_t resolv_conf_changed = (time_t)NULL;
+	struct stat s;
 
+	/* This makes the glibc re-read resolv.conf, if it changed
+	 * since our startup. 
+	 * Why doesn't the glibc do it by itself?
+	 */
+	if (stat("/etc/resolv.conf", &s) == 0) {
+		if (s.st_mtime > resolv_conf_changed) {
+			resolv_conf_changed = s.st_mtime;
+			res_init();
+		}
+	} /* else
+		we'll have bigger problems. */
+#endif /*G_OS_UNIX*/
+}
 
 static gboolean
 weather_http_receive_data_idle (gpointer user_data)
@@ -134,6 +155,9 @@ weather_http_receive_data_idle (gpointer user_data)
   /* set the current time */
   g_get_current_time (&timeout);
 
+  /* force the libc to get resolvers right, if they changed for some reason */
+  refresh_resolvers();
+
   /* try to get the hostname */
   host = gethostbyname (connection->proxy_host ? connection->proxy_host : connection->hostname);
   if (G_UNLIKELY (host == NULL))
@@ -193,7 +217,11 @@ weather_http_receive_data_idle (gpointer user_data)
   if (connection->proxy_host)
     request = g_strdup_printf ("GET http://%s%s HTTP/1.0\r\n\r\n", connection->hostname, connection->url);
   else
-    request = g_strdup_printf ("GET %s HTTP/1.0\r\nHost: %s\r\n\r\n", connection->url, connection->hostname);
+    request = g_strdup_printf ("GET %s HTTP/1.1\r\n"
+    				"Host: %s\r\n"
+				"Connection: close\r\n"
+				"\r\n", 
+				connection->url, connection->hostname);
 
   /* send the request */
   for (m = 0, n = strlen (request); m < n;)
