@@ -1,4 +1,4 @@
-/*  $Id: weather.h 2366 2007-01-15 19:10:23Z nick $
+/*  $Id: weather.h 7539 2009-06-12 16:39:42Z colin $
  *
  *  Copyright (c) 2003-2007 Xfce Development Team
  * 
@@ -22,6 +22,9 @@
 
 #include <libxfce4panel/xfce-panel-plugin.h>
 #include <libxfce4util/libxfce4util.h>
+#define PLUGIN_WEBSITE   "http://goodies.xfce.org/projects/panel-plugins/xfce4-weather-plugin"
+#define PARTNER_ID       "1121946239"
+#define LICENSE_KEY      "3c4cd39ee5dec84f"
 
 G_BEGIN_DECLS
 
@@ -29,8 +32,13 @@ typedef struct
 {
   XfcePanelPlugin *plugin;
 
+#if !GTK_CHECK_VERSION(2,12,0)
   GtkTooltips     *tooltips;
+#endif
 
+  GtkWidget       *top_vbox;
+  GtkWidget       *top_hbox;
+  GtkWidget       *vbox_center_scrollbox;
   GtkWidget       *scrollbox;
   GtkWidget       *iconimage;
   GtkWidget       *tooltipbox;
@@ -39,13 +47,11 @@ typedef struct
 
   GArray          *labels;
 
-  GtkIconSize      iconsize;
-
   gint             size;
+  GtkOrientation   orientation;
   gint             updatetimeout;
 
   gchar           *location_code;
-
   units            unit;
 
   xml_weather     *weatherdata;
